==> web2sms_0.1.2-5.tar.gz: web2sms-0.1.2/src/messagetextfield.cpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

// Local includes
#include "messagetextfield.hpp"
#include "providers/qgsmcodec.h"

// Global includes
#include <QtGui/QKeyEvent>

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class MessageTextFieldPrivate
{
public:
  MessageTextFieldPrivate()
  : codec(&gsmCodec)
  {
  }

  QGsmCodec gsmCodec;
  QTextCodec* codec;
};

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

MessageTextField::MessageTextField(QWidget* parent /* = 0 */)
: QPlainTextEdit(parent)
, d(new MessageTextFieldPrivate)
{
}

//////////////////////////////////////////////////////////////////////////

MessageTextField::~MessageTextField()
{
  delete d;
}

//////////////////////////////////////////////////////////////////////////

/*void MessageTextField::setCodec(QTextCodec* codec)
{
  if ( d->codec == codec )
    return;

  d->codec = codec;
}

//////////////////////////////////////////////////////////////////////////

QTextCodec* MessageTextField::codec() const
{
  return d->codec;
}*/

//////////////////////////////////////////////////////////////////////////

void MessageTextField::keyPressEvent(QKeyEvent* event)
{
  // Get the entered text
  QString text = event->text();
  if ( !text.isEmpty() && (text[0].isPrint() || text[0] == QLatin1Char('\n')) )
  {
    // Get the two byte code
    unsigned short twoByte = d->gsmCodec.twoByteFromUnicode( text.at(0) );

    if ( twoByte == 0x10 ) // Unsupported character
    {
      // Trash the event
      event->setAccepted(false);
      return;
    }
  }

  QPlainTextEdit::keyPressEvent(event);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

==> web2sms_0.1.2-7.tar.gz: web2sms-0.1.2/src/messagetextfield.cpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

// Local includes
#include "messagetextfield.hpp"
#include "providers/qgsmcodec.h"

// Global includes
#include <QtGui/QKeyEvent>
#include <QtGui/QPainter>
#include <QtGui/QFontMetrics>

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class MessageTextFieldPrivate
{
public:
  MessageTextFieldPrivate()
  : codec(&gsmCodec)
  {
  }

  QGsmCodec gsmCodec;
  QTextCodec* codec;
};

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

MessageTextField::MessageTextField(QWidget* parent /* = 0 */)
: QPlainTextEdit(parent)
, d(new MessageTextFieldPrivate)
{
#ifdef Q_WS_MAEMO_5
  // Adjust the palette a little bit to stay with the Maemo style
  QPalette palette = this->palette();
  palette.setColor(QPalette::Text, palette.color(QPalette::Base));
  palette.setColor(QPalette::Base, palette.color(QPalette::Window));
  setPalette(palette);

  // Maemo style has no frame
  setFrameShape(QFrame::NoFrame);
#endif // Q_WS_MAEMO_5
}

//////////////////////////////////////////////////////////////////////////

MessageTextField::~MessageTextField()
{
  delete d;
}

//////////////////////////////////////////////////////////////////////////

/*void MessageTextField::setCodec(QTextCodec* codec)
{
  if ( d->codec == codec )
    return;

  d->codec = codec;
}

//////////////////////////////////////////////////////////////////////////

QTextCodec* MessageTextField::codec() const
{
  return d->codec;
}*/

//////////////////////////////////////////////////////////////////////////

void MessageTextField::keyPressEvent(QKeyEvent* event)
{
  // Get the entered text
  QString text = event->text();
  if ( !text.isEmpty() && (text[0].isPrint() || text[0] == QLatin1Char('\n')) )
  {
    // Get the two byte code
    unsigned short twoByte = d->gsmCodec.twoByteFromUnicode( text.at(0) );

    if ( twoByte == 0x10 ) // Unsupported character
    {
      // Trash the event
      event->setAccepted(false);
      return;
    }
  }

  QPlainTextEdit::keyPressEvent(event);
}

//////////////////////////////////////////////////////////////////////////

void MessageTextField::paintEvent(QPaintEvent* event)
{
#ifdef Q_WS_MAEMO_5
  // Draw the underlines like in the Maemo conversations application
  QFontMetrics fontMetrics = this->fontMetrics();
  QRect rect = this->rect();

  // The line color is taken from the Conversations application
  QColor lineColor(32, 32, 32);
  
  // Setup the painter
  QPainter painter;
  painter.begin(viewport());
  painter.setPen( QPen(lineColor) );

  // Define a jump offset
  int jump = fontMetrics.lineSpacing(); //fontMetrics.ascent() + fontMetrics.underlinePos();

  // Draw the lines
  for(int y=contentOffset().y()+jump; y < rect.height(); y += jump)
    painter.drawLine(rect.left(), y, rect.right(), y);

  painter.end();
#endif // Q_WS_MAEMO_5

  QPlainTextEdit::paintEvent(event);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
